pub fn source_port(source: &LinkSource) -> Option<Port>Expand description
The source Port a link ultimately reads from, through any LinkSource::Select
wrappers; None for a literal or variable source.
pub fn source_port(source: &LinkSource) -> Option<Port>The source Port a link ultimately reads from, through any LinkSource::Select
wrappers; None for a literal or variable source.